@@ -1,6 +1,12 @@
 gSquare = function(target, dataset, xIndex, csIndex, dataInfo=NULL, univariateModels=NULL, hash = FALSE, stat_hash=NULL, pvalue_hash=NULL)
 {
   #Conditional Independence test based on the G test of independence (log likelihood ratio  test)
+  #Suggested package in order to use this test: pcalg
+  
+  if(requireNamespace("pcalg", quietly = TRUE, warn.conflicts = FALSE) == FALSE){
+    warning("You have to load the package 'pcalg' in order to use the gSquare test");
+    return(NULL);
+  }
   
   csIndex[which(is.na(csIndex))] = 0;
   
